@@ -14,7 +14,7 @@ use Getopt::Long qw(:config no_auto_abbrev no_ignore_case);
 use Perl::Strip;
 use Pod::Usage 'pod2usage';
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 our $IGNORE_FILE = [
     qr/\.pod$/,
@@ -213,7 +213,8 @@ For tutorial, please look at L<App::FatPacker::Simple::Tutorial>.
 
 =head1 MOTIVATION
 
-App::FatPacker::Simple is an alternative frontend for L<App::FatPacker>.
+App::FatPacker::Simple is an alternative for L<App::FatPacker>'s
+C<fatpack file> command.
 Let me explain why I wrote this module.
 
 L<App::FatPacker> brings more portability to Perl, that is totally awesome.
